==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_da.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=da
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'alene for fremtidige artikler (ingen opdatering af databasen).',
	'bouton_radio_articles_tous' => 'for alle artikler uden undtagelse.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'for alle artikler med aktivt tilknyttet forum.',
	'bouton_radio_enregistrement_obligatoire' => 'Tvungen registrering (brugere skal give sig til kende ved at oplyse deres e-mail-adresse for at kunne komme med indlæg).',
	'bouton_radio_moderation_priori' => 'Forhåndsgodkendelse (bidrag vises først efter at de er godkendt af administratorer).', # MODIF
	'bouton_radio_modere_abonnement' => 'Kun for abonnenter (bidragydere skal oplyse e-mail-adresse, før de kan indsende bidrag)',
	'bouton_radio_modere_posteriori' => 'Efterfølgende godkendelse (bidrag er straks synlige men en administrator kan senere slette dem)', # MODIF
	'bouton_radio_modere_priori' => 'Forhåndsgodkendelse', # MODIF
	'bouton_radio_publication_immediate' => 'Indlæg offentliggøres straks (bidrag vises straks efter at de er sendt, administratorer kan slette dem senere).',

	// F
	'form_pet_message_commentaire' => 'Meddelelse eller kommentar?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Du har ikke mere adgang til disse forummer',
	'forum_attention_dix_caracteres' => '<b>Advarsel!</b> dit indlæg er mindre end ti tegn langt.', # MODIF
	'forum_attention_trois_caracteres' => '<b>Advarsel!</b> dit emne er mindre end tre tegn langt.', # MODIF
	'forum_avez_selectionne' => 'Du har valgt:',
	'forum_cliquer_retour' => 'Klik <a href=\'@retour_forum@\'>her</a> for at fortsætte.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Dette forum benytter forhåndsgodkendelse: dit bidrag vil først blive offentliggjort, når det er godkendt af en administrator.', # MODIF
	'forum_lien_hyper' => '<b>Hypertekst link</b> (valgfrit)', # MODIF
	'forum_message_definitif' => 'Endeligt indlæg: send til webstedet',
	'forum_message_trop_long' => 'Dit indlæg er for langt. Maksimal længde er 20.000 tegn.', # MODIF
	'forum_ne_repondez_pas' => 'Undlad at besvare denne e-mail, men gå i stedet til forummet på denne adresse:', # MODIF
	'forum_page_url' => '(Hvis dit indlæg henviser til en artikel, der er offentliggjort på Internettet, eller til en side der indeholder yderligere oplysninger, så angiv venligst sidens titel og dens adresse eller URL nedenfor).',
	'forum_poste_par' => 'Indlæg @parauteur@ som svar på din artikel.', # MODIF
	'forum_qui_etes_vous' => '<b>Hvem er du?</b> (valgfrit)', # MODIF
	'forum_texte' => 'Indlæggets tekst:', # MODIF
	'forum_titre' => 'Titel:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Kontroller gyldighed',
	'forum_voir_avant' => 'Vis indlæg før indsendelse', # MODIF
	'forum_votre_email' => 'Din e-mail-adresse:', # MODIF
	'forum_votre_nom' => 'Dit navn (eller alias):', # MODIF
	'forum_vous_enregistrer' => 'Før du kan deltage i dette forum,
		skal du tilmelde dig. Indtast venligst nedenfor de
		personlige adgangsoplysninger, du har fået tilsendt.
		Hvis du ikke allerede har tilmeldt dig, skal du gøre det.',
	'forum_vous_inscrire' => 'tilmeld dig </a> først.', # MODIF

	// I
	'icone_poster_message' => 'Opret meddelelse',
	'icone_suivi_forum' => 'Opfølgning i offentligt forum: @nb_forums@ bidrag',
	'icone_suivi_forums' => 'Administrer forummer',
	'icone_supprimer_message' => 'Slet denne meddelelse',
	'icone_valider_message' => 'Godkend meddelelse',
	'info_activer_forum_public' => '<i>For at åbne op for offentlige forummer, skal du vælge, hvordan deres godkendelsesprocedure skal være som standard:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Anvend denne godkendelsesprocedure:',
	'info_desactiver_forum_public' => 'Fravælg brugen af offentlige forummer. Der kan åbnes op for offentlige forummer fra gang til gang i forhold til artikler.
De vil være lukkede i forhold til afsnit, meddelelser osv..',
	'info_envoi_forum' => 'Send indlæg i forummer til artiklernes forfattere',
	'info_fonctionnement_forum' => 'Forummets funktionsmåde:',
	'info_gauche_suivi_forum_2' => '<i>Forumopfølgning</i> er et administrationsværktøj (ikke et diskussions- eller redigeringsområde). Siden viser alle indlæg i webstedets forummer, både på det offentlige og det private område, og giver dig mulighed for at administrere indlæggene.', # MODIF
	'info_liens_syndiques_3' => 'forummer',
	'info_liens_syndiques_4' => 'er',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'er',
	'info_liens_syndiques_7' => 'afventer godkendelse.',
	'info_mode_fonctionnement_defaut_forum_public' => 'Standard funktionsmåde for offentlige forummer',
	'info_option_email' => 'Når en besøgende på webstedet sender en meddelelse til forummet, som drejer sig om denne artikel, kan artiklens forfatter få underretning om meddelelsen via e-mail. Ønsker du at bruge denne mulighed?', # MODIF
	'info_pas_de_forum' => 'intet forum',
	'item_activer_forum_administrateur' => 'Slå funktionen administratorforum til',
	'item_desactiver_forum_administrateur' => 'Slå funktionen administratorforum fra',

	// L
	'lien_reponse_article' => 'Kommenter denne artikel',
	'lien_reponse_breve_2' => 'Kommenter denne nyhed',
	'lien_reponse_rubrique' => 'Kommenter dette afsnit',
	'lien_reponse_site_reference' => 'Kommenter dette link:', # MODIF

	// O
	'onglet_messages_internes' => 'Interne meddelelser',
	'onglet_messages_publics' => 'Offentlige meddelelser',
	'onglet_messages_vide' => 'Meddelelser uden tekst',

	// R
	'repondre_message' => 'Lav et svar på dette indlæg',

	// T
	'titre_cadre_forum_administrateur' => 'Administratorers private forum',
	'titre_cadre_forum_interne' => 'Internt forum',
	'titre_forum' => 'Internt forum',
	'titre_forum_suivi' => 'Opfølgning på forummer',
	'titre_page_forum_suivi' => 'Opfølgning på forummer'
);

==> spip_4.2.14+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_da.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=da
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'alene for fremtidige artikler (ingen opdatering af databasen).',
	'bouton_radio_articles_tous' => 'for alle artikler uden undtagelse.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'for alle artikler med aktivt tilknyttet forum.',
	'bouton_radio_enregistrement_obligatoire' => 'Tvungen registrering (brugere skal give sig til kende ved at oplyse deres e-mail-adresse for at kunne komme med indlæg).',
	'bouton_radio_moderation_priori' => 'Forhåndsgodkendelse (bidrag vises først efter at de er godkendt af administratorer).', # MODIF
	'bouton_radio_modere_abonnement' => 'Kun for abonnenter (bidragydere skal oplyse e-mail-adresse, før de kan indsende bidrag)',
	'bouton_radio_modere_posteriori' => 'Efterfølgende godkendelse (bidrag er straks synlige men en administrator kan senere slette dem)', # MODIF
	'bouton_radio_modere_priori' => 'Forhåndsgodkendelse', # MODIF
	'bouton_radio_publication_immediate' => 'Indlæg offentliggøres straks (bidrag vises straks efter at de er sendt, administratorer kan slette dem senere).',

	// F
	'form_pet_message_commentaire' => 'Meddelelse eller kommentar?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Du har ikke mere adgang til disse forummer',
	'forum_attention_dix_caracteres' => '<b>Advarsel!</b> dit indlæg er mindre end ti tegn langt.', # MODIF
	'forum_attention_trois_caracteres' => '<b>Advarsel!</b> dit emne er mindre end tre tegn langt.', # MODIF
	'forum_avez_selectionne' => 'Du har valgt:',
	'forum_cliquer_retour' => 'Klik <a href=\'@retour_forum@\'>her</a> for at fortsætte.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Dette forum benytter forhåndsgodkendelse: dit bidrag vil først blive offentliggjort, når det er godkendt af en administrator.', # MODIF
	'forum_lien_hyper' => '<b>Hypertekst link</b> (valgfrit)', # MODIF
	'forum_message_definitif' => 'Endeligt indlæg: send til webstedet',
	'forum_message_trop_long' => 'Dit indlæg er for langt. Maksimal længde er 20.000 tegn.', # MODIF
	'forum_ne_repondez_pas' => 'Undlad at besvare denne e-mail, men gå i stedet til forummet på denne adresse:', # MODIF
	'forum_page_url' => '(Hvis dit indlæg henviser til en artikel, der er offentliggjort på Internettet, eller til en side der indeholder yderligere oplysninger, så angiv venligst sidens titel og dens adresse eller URL nedenfor).',
	'forum_poste_par' => 'Indlæg @parauteur@ som svar på din artikel.', # MODIF
	'forum_qui_etes_vous' => '<b>Hvem er du?</b> (valgfrit)', # MODIF
	'forum_texte' => 'Indlæggets tekst:', # MODIF
	'forum_titre' => 'Titel:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Kontroller gyldighed',
	'forum_voir_avant' => 'Vis indlæg før indsendelse', # MODIF
	'forum_votre_email' => 'Din e-mail-adresse:', # MODIF
	'forum_votre_nom' => 'Dit navn (eller alias):', # MODIF
	'forum_vous_enregistrer' => 'Før du kan deltage i dette forum,
		skal du tilmelde dig. Indtast venligst nedenfor de
		personlige adgangsoplysninger, du har fået tilsendt.
		Hvis du ikke allerede har tilmeldt dig, skal du gøre det.',
	'forum_vous_inscrire' => 'tilmeld dig </a> først.', # MODIF

	// I
	'icone_poster_message' => 'Opret meddelelse',
	'icone_suivi_forum' => 'Opfølgning i offentligt forum: @nb_forums@ bidrag',
	'icone_suivi_forums' => 'Administrer forummer',
	'icone_supprimer_message' => 'Slet denne meddelelse',
	'icone_valider_message' => 'Godkend meddelelse',
	'info_activer_forum_public' => '<i>For at åbne op for offentlige forummer, skal du vælge, hvordan deres godkendelsesprocedure skal være som standard:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Anvend denne godkendelsesprocedure:',
	'info_desactiver_forum_public' => 'Fravælg brugen af offentlige forummer. Der kan åbnes op for offentlige forummer fra gang til gang i forhold til artikler.
De vil være lukkede i forhold til afsnit, meddelelser osv..',
	'info_envoi_forum' => 'Send indlæg i forummer til artiklernes forfattere',
	'info_fonctionnement_forum' => 'Forummets funktionsmåde:',
	'info_gauche_suivi_forum_2' => '<i>Forumopfølgning</i> er et administrationsværktøj (ikke et diskussions- eller redigeringsområde). Siden viser alle indlæg i webstedets forummer, både på det offentlige og det private område, og giver dig mulighed for at administrere indlæggene.', # MODIF
	'info_liens_syndiques_3' => 'forummer',
	'info_liens_syndiques_4' => 'er',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'er',
	'info_liens_syndiques_7' => 'afventer godkendelse.',
	'info_mode_fonctionnement_defaut_forum_public' => 'Standard funktionsmåde for offentlige forummer',
	'info_option_email' => 'Når en besøgende på webstedet sender en meddelelse til forummet, som drejer sig om denne artikel, kan artiklens forfatter få underretning om meddelelsen via e-mail. Ønsker du at bruge denne mulighed?', # MODIF
	'info_pas_de_forum' => 'intet forum',
	'item_activer_forum_administrateur' => 'Slå funktionen administratorforum til',
	'item_desactiver_forum_administrateur' => 'Slå funktionen administratorforum fra',

	// L
	'lien_reponse_article' => 'Kommenter denne artikel',
	'lien_reponse_breve_2' => 'Kommenter denne nyhed',
	'lien_reponse_rubrique' => 'Kommenter dette afsnit',
	'lien_reponse_site_reference' => 'Kommenter dette link:', # MODIF

	// O
	'onglet_messages_internes' => 'Interne meddelelser',
	'onglet_messages_publics' => 'Offentlige meddelelser',
	'onglet_messages_vide' => 'Meddelelser uden tekst',

	// R
	'repondre_message' => 'Lav et svar på dette indlæg',

	// T
	'titre_cadre_forum_administrateur' => 'Administratorers private forum',
	'titre_cadre_forum_interne' => 'Internt forum',
	'titre_forum' => 'Internt forum',
	'titre_forum_suivi' => 'Opfølgning på forummer',
	'titre_page_forum_suivi' => 'Opfølgning på forummer',
];
